Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCustomParamChangeProposalHandler ¶
func NewCustomParamChangeProposalHandler(paramKeeper paramsKeeper, bankKeeper bankkeeper.Keeper) govtypes.Handler
NewCustomParamChangeProposalHandler creates a new governance Handler for a ParamChangeProposal that includes additional validation logic for the minGasPrices parameter using bankKeeper.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.